@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Sequence
 
-from botocore.response import StreamingBody
-
 from .literals import StatementStatusStringType, StatusStringType
 
 if sys.version_info >= (3, 9):
@@ -244,7 +242,7 @@ ExecuteStatementOutputTypeDef = TypedDict(
 FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
-        "blobValue": StreamingBody,
+        "blobValue": bytes,
         "booleanValue": bool,
         "doubleValue": float,
         "isNull": bool,
